function double_ceph, t, p0, pp=pp
;+
; NAME:
;      DOUBLE_CEPH
;
;
; PURPOSE:
;        Generate cephied light-curve in 2 bands simultaneously
;
;
; CATEGORY:
;
;
;
; CALLING SEQUENCE:
;
;
;
; INPUTS:
;t=dates of light-curve points (days)
;p0(0)=m_0_i (average I band magnitude)
;p0(1)=m_0_b  (average B band magnitude)
;p0(2)=Period  (days)
;p0(3)=phase shift (days)
;p0(4)=t_break (first element that has b-band data)
;p0(5-12)=alpha_i 
;p0(13-20)=beta_i
;p0(21-28)=alpha_b
;p0(29-36)=beta_b
;
;
; OPTIONAL INPUTS:
;
;
;
; KEYWORD PARAMETERS:
;
;
;
; OUTPUTS:
;
;
;
; OPTIONAL OUTPUTS:
;
;
;
; COMMON BLOCKS:
;
;
;
; SIDE EFFECTS:
;
;
;
; RESTRICTIONS:
;
;
;
; PROCEDURE:
;
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
;
;-





;when passing to mpfit, hold p0(4) constant

  if keyword_set(pp) then p0=pp_ab(p0) ;if the input it Fourier
                                ;components of the form:
                                ;P*sin(a+Phase) this converts to the
                                ;form:  Asin(x)+bcos(x)


n_extra=5 ;number of extra elements ahead of all the alphas and betas

na=(n_elements(p0)-n_extra)/4 ;number of alpha-elements per band

;n_extra:n_extra+na*2-1
;n_extra+na*2:n_extra+na*4-1

;pi=[p0(0), p0(2), p0(3), p0(5:20)] 
;pb=[p0(1), p0(2), p0(3), p0(21:36)]
pi=[p0(0), p0(2:3), p0(n_extra:n_extra+na*2-1)] 
pb=[p0(1:3), p0(n_extra+na*2:n_extra+na*4-1)]

ti=t(0:p0(4)-1)
tb=t(p0(4):n_elements(t)-1)

lc_i=f_comp(ti,pi)
lc_b=f_comp(tb,pb)
result=[lc_i,lc_b]

return, result
end


function pp_ab, p0
;take a power_phase pair and switch to A_B pair
n_extra=5 ;number of extra elements ahead of all the alphas and betas

na=(n_elements(p0)-n_extra)/4 ;number of alpha-elements per band

result=p0

Po_i=p0(n_extra: n_extra+na-1) ;powers
ph_i=p0(n_extra+na: n_extra+2*na-1) ;phases
po_v=p0(n_extra+2*na:n_extra+3*na-1)
ph_v=p0(n_extra+3*na: n_extra+4*na-1)

result(n_extra: n_extra+na-1)=po_i*cos(ph_i) ;i-band alpha
result( n_extra+na: n_extra+2*na-1)=po_i*sin(ph_i)        ;i-band beta
result(n_extra+2*na:n_extra+3*na-1)=po_v*cos(ph_v)  ;v-alpha
result(n_extra+3*na: n_extra+4*na-1)=po_v*sin(ph_v)  ;v-beta

return, result
end


function ab_pp, p0
;convert a ab pair to phase power-pair

n_extra=5 ;number of extra elements ahead of all the alphas and betas

na=(n_elements(p0)-n_extra)/4 ;number of alpha-elements per band
result=p0
alpha_i=p0(n_extra: n_extra+na-1)
beta_i=p0(n_extra+na: n_extra+2*na-1)

alpha_v=p0(n_extra+2*na:n_extra+3*na-1)
beta_v=p0(n_extra+3*na: n_extra+4*na-1)

ph_i=atan(beta_i,alpha_i)
po_i=alpha_i/cos(ph_i)

ph_v=atan(beta_v,alpha_v)
po_v=alpha_v/cos(ph_v)

;stop
result( n_extra: n_extra+na-1)=po_i
result(n_extra+na: n_extra+2*na-1)=ph_i
result(n_extra+2*na:n_extra+3*na-1)=po_v
result(n_extra+3*na: n_extra+4*na-1)=ph_v



return, result
end

