;;;example code using template light curves.

;in this example, I use the code to generate a fake light-curve, add
;   noise to it, then demonstrate various ways of fitting the light curve.


;restore the LMC short period structure called ceph_struc
restore, 'lmc_shortp.sav'
t=[findgen(10),findgen(10)] ;generate dates for the LC

p0=[5.d0,6, 4.5, 2., 10 ]  ;parameters for the LC.  This LC will have an
                                ;average m_i=5, m_v=6, period=4.5
                                ;days, phase shift=2 days, and the 10
                                ;signifies that t(0:9) is for the
                                ;I-band while t(10:19) are for V.


light_curves=gen_lc(t, p0, struc=ceph_struc, pcoef=pcoef) ;generate a
                                ;model light curve


mplot, t, light_curves, psym=2, xtitle='Date (days)', ytitle='mi,mv', $
title='Starting Light Curve' ;plot up the curve


print, 'type .c to continue with the example'
stop

;add 0.05 mags of Gaussian noise to the LCs
seed=6  ;for repeatability
noise_level=.05
noise=randomn(seed,20)*noise_level
light_curves=light_curves+noise


;now try fitting the light curve and plot up the fit:

fit_params=template_fit( t(0:9), light_curves(0:9), $
                   light_curves(0:9)*0+noise_level, t(10:19), $
                   light_curves(10:19), $
                   light_curves(10:19)*0+noise_level, $
                   short_struc=ceph_struc, long_struc=ceph_struc, $
                   norm_err=norm_err, red_chi=red_chi, yfit=yfit, /plots)
;OK, that's a messy call. to break down each term
; t(0:9) :  dates for the I-band data
; light_curves(0:9) :  the I-band magnitudes
; light_curves(0:9)*0+noise_level : RMS uncertainty in each I-band
;                                   magnitude
; t(10:19) : dates for the V-band data
; light_curves(10:19) : the V-band magnitudes
;light_curves(10:19)*0+noise_level : V magnitude errors
;short_struc=ceph_struc : When fitting a period shorter than 10 days,
;                       use this structure
;long_struc=ceph_struc : When fitting a period longer than 10 days,
;                      use this structure.  
;norm_err=norm_err : return the normalized uncertainties of the fit
;                  parameters
; red_chi=red_chi : return the reduced chi^2 value
;yfit=yfit :  return the fitted curve
;/plots:  Make a pretty plot of the best-fit curve.  





print, 'input paramenters:  '
print, '      mi                 mv            Period            phase        10'
print, p0
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi

print, 'Hooray, the fitted parameters match the input and chi-squared is close to unity'


print, 'type .c to continue with the example'
stop

print, 'The fitted curve looks bad with the sparse sampling--now make a pretty smooth curve'



x=fold(t,4.5)
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes', $
title='light curve with well sampled best fit.' 
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fit_params(2)
x=[x,x]

;here's an easy way to plot the two filters at the same time
oplot_split, fold(x,fit_params(2)), gen_lc(x,[fit_params[0:3] $
              ,1001],struc=ceph_struc),1001 

 

print, 'type .c to continue with the example'
stop

 print, 'now to do the same fit, but leave the LC shape parameters as free variables'


fit_params=template_fit( t(0:9), light_curves(0:9), $
                   light_curves(0:9)*0+noise_level, t(10:19), $
                   light_curves(10:19), $
                   light_curves(10:19)*0+noise_level, $
                   short_struc=ceph_struc, long_struc=ceph_struc, $
                         norm_err=norm_err, red_chi=red_chi, $
                         yfit=yfit, /plots, ns=4)




;same as before, but now ns=4 leaves all 4 shape parameters free
print, 'input paramenters:  '
print, '      mi          mv      Period       phase        10'
print, pcoef
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi




x=fold(t,4.5)
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes' , $
title='light curve shape parameters left free'
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fit_params(2)
x=[x,x]

oplot_split, fold(x,fit_params(2)), gen_lc(x,[fit_params[0:3] $
              ,1001],struc=ceph_struc),1001 

print, 'Hooray, the fit worked again.  Of course it took a lot longer trying to fit those extra shape parameters, but it still converged correctly.  Notice the reduced chi-squared hardly changed, so there is not much information in those extra shape parameters'


print, 'type .c to continue with the example'
stop


print, 'Now to try fitting this LMC based light-curve with an SMC template'

restore, 'smc_pca.sav'  ;this will overwrite the old ceph_struc variable


fit_params=template_fit( t(0:9), light_curves(0:9), $
                   light_curves(0:9)*0+noise_level, t(10:19), $
                   light_curves(10:19), $
                   light_curves(10:19)*0+noise_level, $
                   short_struc=ceph_struc, long_struc=ceph_struc, $
                   norm_err=norm_err, red_chi=red_chi, yfit=yfit, /plots)

print, 'input paramenters:  '
print, '      mi          mv      Period       phase        10'
print, p0
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi

x=fold(t,4.5)
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes', $
title='LMC star fit with SMC template'
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fit_params(2)
x=[x,x]

oplot_split, fold(x,fit_params(2)), gen_lc(x,[fit_params[0:3] $
              ,1001],struc=ceph_struc),1001 


print, 'Hooray, the fit still looks pretty good.  '

print, 'type .c to continue with the example'
stop


print, 'Now to go all out and try fitting an overtone template'

restore, 'overtone_pca.sav'    ;this replaces the ceph_struc structure
                            ;with the overtone structure

fit_params=template_fit( t(0:9), light_curves(0:9), $
                   light_curves(0:9)*0+noise_level, t(10:19), $
                   light_curves(10:19), $
                   light_curves(10:19)*0+noise_level, $
                   short_struc=ceph_struc, long_struc=ceph_struc, $
                   norm_err=norm_err, red_chi=red_chi, yfit=yfit, /plots)

print, 'input paramenters:  '
print, '      mi          mv      Period       phase        10'
print, p0
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi

fitp=fit_params(2)

x=fold(t,fitp)
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes' 
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fitp;fit_params(2)
x=[x,x]

oplot_split, fold(x,fitp), gen_lc(x,[fit_params[0:3] $
              ,1001],struc=ceph_struc),1001 

print, 'Hooray, the fit failed miserably, but we used the wrong template and there is a reduced chi^2 of 7.2 so we know the fit should be bad'


print, 'type .c to continue with the example'
stop

print, 'Now a simple test to show the star is not constant'

n=n_elements(light_curves)

m1=wtd_mean(light_curves(0:p0(4)-1), $
            light_curves(0:p0(4)-1)*0+noise_level)
m2=wtd_mean(light_curves(p0(4):n-1), $
            light_curves(p0(4):n-1)*0+noise_level)

;compute the chi^2 of just fitting the stars with a straight line

chi_sq1=total( $
     ((light_curves(0:p0(4)-1)-m1)/$
      (light_curves(0:p0(4)-1)*0+noise_level))^2)/(n_elements(light_curves(0:p0(4)-1))-1 )

chi_sq2=total( $
     ((light_curves(p0(4):n-1)-m2)/$
      (light_curves(p0(4):n-1)*0+noise_level))^2)/(n_elements(light_curves(p0(4):n-1))-1 )

print, 'total reduced-chi^2 assuming the star is non-variable = ', $
chi_sq1+chi_sq2

;if we were really motivated, we could loop over and make sure there's
;   not just 1 or two discrepant points driving up the constant fit.  


end
