function gen_lc, x, p0, struct=struct, pcoef=pcoef;, plots=plots
;+
; NAME:
;     GEN_LC
;
;
; PURPOSE:
; Generate a light-curve based on a template.  Designed to be used
; with mpfit to find magnitudes, periods, and phases of observed light
; curves.  Generates 2 filters simultaneously
;
;
; CATEGORY:
;     Curve fitting
;
;
; CALLING SEQUENCE:
;      result=gen_lc(x,p0,struct=struct)
;
;
; INPUTS:
;    x - the dates for the requested light curve (days)
;p0(0)=m_0_i  -- average I-band magnitude
;p0(1)=m_0_b  -- average V-band magnitude
;p0(2)=Period (days)  
;p0(3)=phase shift (days)
;p0(4)=t_break (first element that has V-band data)
;p0(5:8)=pca1-pca4 (optional)  
;
;    struct -- structure that has the principle component analysis
; results in it.
;
;
; OPTIONAL INPUTS:
;
;
;
; KEYWORD PARAMETERS:
;
;
;
; OUTPUTS:
;  Light curves.  results(0:p0(4)) is the I-band light-curve while
; results(p0(4)+1:n_elements(results)-1) has the V-band
;
;  Plots keyword added to show how the pca components add on
;
; SIDE EFFECTS:
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
; Written 2/07  PY
;-



;need to convert p0 into a list of p0 to pass 
p=p0

if n_elements(p) lt 9 then begin ;use the poly_fits to fill in the
                                ;pca1-pca4 coeffs
c_need=9-n_elements(p0)
    for i=4-c_need,3 do begin
      coef=poly(alog10(p0(2)), struct.poly_fits(i,*))
      p=[p,coef]
    endfor

endif

pcoef=p


;generate the alpha and beta pairs
albes=struct.AVE_VALS+p(5:8)##struct.eigenvectors(*,0:3)


p=[p[0:4], albes]
result=double_ceph(x,p)






return, result

end
